#ifndef INC_XIMCINT_H
#define INC_XIMCINT_H

#if defined(__cplusplus)
extern "C"
{
#endif


/*
 --------------------------------------------
   BEGIN OF GENERATED metadata declarations
 --------------------------------------------
*/

	#define XIMC_METALEN_SERVICE_COMMAND_WRITE_DATA_IMPL_DATA 128


/*
 --------------------------------------------
   BEGIN OF GENERATED function declarations
 --------------------------------------------
*/
/** 
	* \english
	* Return device state.
	* Useful function that fills structure with snapshot of controller state, including speed, position and boolean flags.
	* @param id an identifier of device
	* @param[out] status structure with snapshot of controller state
	* \endenglish
	* \russian
	* Возвращает информацию о текущем состоянии устройства.
	* @param id идентификатор устройства
	* @param[out] status структура с информацией о текущем состоянии устройства
	* \endrussian
	*/
	result_t get_status_impl (device_t id, status_t* status);

	result_t get_status_impl_calb (device_t id, status_calb_t* status_calb, const calibration_t* calibration);

	result_t get_device_information_impl_unsynced (device_t id, device_information_t* device_information);

/** 
	* \english
	* Return device information.
	* All fields must point to allocated string buffers with at least 10 bytes.
	* Works with both raw or initialized device.
	* @param id an identifier of device
	* @param[out] device_information device information
	* \endenglish
	* \russian
	* Возвращает информацию об устройстве.
	* Все входные параметры должны быть указателями на выделенные области памяти длиной не менее 10 байт.
	* Команда доступна как из инициализированного состояния, так и из исходного.
	* @param id идентификатор устройства.
	* @param[out] device_information информация об устройстве
	* \endrussian
	*/
	result_t get_device_information_impl (device_t id, device_information_t* device_information);

/** 
	* \english
	* The command for clear controller FRAM.
	* The memory is cleared by filling the whole memory byte 0x00.
	* After cleaning, the controller restarts.
	* No response to this command.
	* @param id an identifier of device
	* \endenglish
	* \russian
	* Команда очистки FRAM контроллера.
	* Память очищается путем заполнения всего объема памяти байтами 0x00.
	* После очистки контроллер перезагружается. Ответа на эту команду нет.
	* @param id идентификатор устройства
	* \endrussian
	*/
	result_t service_command_clear_fram_impl (device_t id);

/** 
		* \english
		* Command initiates the transfer of control to firmware. This command is
		* also available from the firmware for compatibility.
		* Result = RESULT_OK, if the transition from the loader in the firmware is
		* possible. After the response to this command is executed transition.
		* Result = RESULT_NO_FIRMWARE, if the firmware is not found.
		* Result = RESULT_ALREADY_IN_FIRMWARE, if this command is called from the firmware.
		* @param id an identifier of device
		* @param[out] sresult command result
		* \endenglish
		* \russian
		* Команда инициирует передачу управления прошивке. Эта команда так же доступна из прошивки,
		* для совместимости.
		* Result = RESULT_OK, если переход из загрузчика в прошивку возможен. После ответа на эту
		* команду выполняется переход.
		* Result = RESULT_NO_FIRMWARE, если прошивка не найдена.
		* Result = RESULT_ALREADY_IN_FIRMWARE, если эта команда была вызвана из прошивки.
		* @param id идентификатор устройства
		* @param[out] sresult результат выполнения команды
		* \endrussian
*/
	result_t service_command_goto_firmware_impl (device_t id, service_result_t*sresult);

	result_t service_command_has_firmware_impl (device_t id, service_result_t*sresult);

/** 
	* \english
	* Write command key to decrypt the firmware.
	* Result = RESULT_OK, if the command loader.
	* Result = RESULT_HARD_ERROR, if at the time of the command there was mistake.
	* Result not available using the library write_key, the field value is processed by the function.
	* Can be used by manufacturer only.
	* @param Name a name of device
	* @param[in] Key protection key. Range: 0..4294967295
	* \endenglish
	* \russian
	* Команда записи ключа для расшифровки прошивки.
	* Result = RESULT_OK, если команда выполнена загрузчиком.
	* Result = RESULT_HARD_ERROR, если во время выполнения команды произошла ошибка.
	* Result не доступен через функцию библиотеки write_key, значение поля обрабатывается внутри функции.
	* Функция используется только производителем.
	* @param Name имя устройства
	* @param[in] Key ключ защиты. Диапазон: 0..4294967295
	* \endrussian
	*/
	result_t service_command_write_key_impl (device_t id, const uint8_t* Key);

	result_t service_command_connect_impl (device_t id);

	result_t service_command_disconnect_impl (device_t id);

/** 
	* \english
	* Writes encoded firmware in the controller flash memory.
	* Result of each packet write is not available. Overall result is available when firmware upload is finished.
	* @param[in] Data[128] Encoded firmware
	* \endenglish
	* \russian
	* Записывает данные (прошивку) во Flash память контроллера.
	* Не возвращает результат выполнения, хотя может завершаться ошибкой.
	* Ошибочность заливки и тип ошибки можно узнать при завершении заливки.
	* @param[in] Data[128] Закодированная прошивка
	* \endrussian
	*/
	result_t service_command_write_data_impl (device_t id, const uint8_t* Data);

/** 
	* \english
	* The reset command controller and go into bootloader mode,
	* for compatibility with the exchange protocol to the loader.
	* No response to this command.
	* \endenglish
	* \russian
	* Команда сброса контроллера и перехода в режим загрузчика, добавлена для
	* совместимости с Протоколом Обмена Загрузчика. Ответа на эту команду нет.
	* \endrussian
	*/
	result_t service_command_reset_impl (device_t id);


/*
 -------------------------
   END OF GENERATED CODE
 -------------------------
*/

#if defined(__cplusplus)
};
#endif

#endif

// vim: ts=4 shiftwidth=4

